from django.utils.functional import SimpleLazyObject

from seo.lib import get_page_meta


class PageMetaMiddleware(object):

    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        request.page_meta = SimpleLazyObject(lambda: get_page_meta(request))
        return self.get_response(request)




from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


def setup_settings(settings, **kwargs):

    settings['MIDDLEWARE'] += [
        'seo.middleware.PageMetaMiddleware'
    ]


class SeoConfig(AppConfig):
    name = 'seo'
    verbose_name = _("SEO")


default_app_config = 'seo.SeoConfig'
